@@ -72,7 +72,7 @@ poly p_One(const ring r);
 
 int p_MinDeg(poly p,intvec *w, const ring R);
 
-long p_DegW(poly p, const short *w, const ring R);
+long p_DegW(poly p, const int *w, const ring R);
 
 /// return TRUE if all monoms have the same component
 BOOLEAN   p_OneComp(poly p, const ring r);
@@ -211,6 +211,7 @@ void      p_ProjectiveUnique(poly p,const ring r);
 
 void      p_ContentForGB(poly p, const ring r);
 void      p_Content(poly p, const ring r);
+void      p_Content_n(poly p, number &c,const ring r);
 #if 1
 // currently only used by Singular/janet
 void      p_SimpleContent(poly p, int s, const ring r);
@@ -1977,6 +1978,7 @@ static inline BOOLEAN p_IsConstant(const poly p, const ring r)
 /// either poly(1)  or gen(k)?!
 static inline BOOLEAN p_IsOne(const poly p, const ring R)
 {
+  if (p == NULL) return FALSE; /* TODO check if 0 == 1 */
   p_Test(p, R);
   return (p_IsConstant(p, R) && n_IsOne(p_GetCoeff(p, R), R->cf));
 }
@@ -2095,8 +2097,8 @@ void p_SetModDeg(intvec *w, ring r);
 /*------------ Jet ----------------------------------*/
 poly pp_Jet(poly p, int m, const ring R);
 poly p_Jet(poly p, int m,const ring R);
-poly pp_JetW(poly p, int m, short *w, const ring R);
-poly p_JetW(poly p, int m, short *w, const ring R);
+poly pp_JetW(poly p, int m, int *w, const ring R);
+poly p_JetW(poly p, int m, int *w, const ring R);
 
 poly n_PermNumber(const number z, const int *par_perm, const int OldPar, const ring src, const ring dst);
 
